[PATCH] fast streams support in include_path
| From: | Gregory Beaver | Date: | Sat, 08 Mar 2008 19:13:13 +0000 |
| Subject: | [PATCH] fast streams support in include_path | ||
| Groups: | php.internals | ||
| Request: | Send a blank email to internals+get-36064@lists.php.net to get a copy of this message | ||
Hi,
Here's the last attempt at streams support in include_path.
After siccing callgrind on the patch, I'm confident it meets performance
requirements. Even in the worst case, it is significantly faster than
PHP 5.2, and insignificantly slower (1%) than the current CVS.
This patch is optimized so that it is:
1% faster than the current implementation for include/require
1% slower than current include_once/require_once implementation
It also fixes a compile warning caused by missing cast from const char *
to char *
Greg